using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using WiimoteLib;

namespace WiiSpaceship
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        //Nintendo Wii 
        Wiimote wm;
        WiimoteState ws;

        //Grafik
        Texture2D ship;

        double shipX = 320, shipY = 240, shipSpeedX, shipSpeedY;
        double angle;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            graphics.PreferredBackBufferWidth = 640;
            graphics.PreferredBackBufferHeight = 480;

            wm = new Wiimote();

            //Bind events
            wm.WiimoteChanged += new WiimoteChangedEventHandler(wm_OnWiimoteChanged);
            wm.WiimoteExtensionChanged += new WiimoteExtensionChangedEventHandler(wm_OnWiimoteExtensionChanged);

            // koppla upp mot wii-kontrollen
            wm.Connect();

            // stll in s att information om IR och acceleration skickas
            // annars skiackas bara information om knapparna
            wm.SetReportType(Wiimote.InputReport.IRAccel, true);
        }

        protected override void Initialize()
        {

            base.Initialize();
        }

        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);
            ship = Content.Load<Texture2D>("ship");
        }

        protected override void UnloadContent()
        {
        }

        protected override void Update(GameTime gameTime)
        {
            int ms = gameTime.ElapsedGameTime.Milliseconds;

            //Accelerera med Wii ;)
            shipSpeedX = ws.AccelState.X;
            shipSpeedY = -ws.AccelState.Y;

            //Flytta skeppet
            shipX += shipSpeedX * ms;
            shipY += shipSpeedY * ms;

            //Se till att skeppet kommer tillbaka
            if (shipX > 700)
                shipX = -50;
            if (shipX < -50)
                shipX = 700;
            if (shipY > 550)
                shipY = -50;
            if (shipY < -50)
                shipY = 550;

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            graphics.GraphicsDevice.Clear(Color.CornflowerBlue);

            spriteBatch.Begin();

            Vector2 origin = new Vector2(ship.Width / 2, ship.Height / 2);
            spriteBatch.Draw(ship, new Vector2((float)shipX, (float)shipY), null, Color.White, (float)angle, origin, 1, SpriteEffects.None, 0);

            spriteBatch.End();

            base.Draw(gameTime);
        }



        void wm_OnWiimoteExtensionChanged(object sender, WiimoteExtensionChangedEventArgs args)
        {
            if (args.Inserted)
                wm.SetReportType(Wiimote.InputReport.IRExtensionAccel, true);    // return extension data
            else
                wm.SetReportType(Wiimote.InputReport.IRAccel, true);            // back to original mode
        }

        void wm_OnWiimoteChanged(object sender, WiimoteChangedEventArgs args)
        {
            // nuvarande information frn kontrollen
            ws = args.WiimoteState;

        }
    }
}
